@@ -40,7 +40,7 @@ BEGIN {
     require Exporter;
 
     # set the version for version checking
-    our $VERSION = 0.36;
+    our $VERSION = 0.37;
 
     # Inherit from Exporter to export functions and variables
     our @ISA = qw(Exporter);
@@ -277,8 +277,10 @@ DEFAULT:  '%D %T %B %L[%P][%l] '
 %T = Time (Uses format of "TimeStamp" below)
 %B = Benchmark
 %L = Log Level
-%l = Line Number
-%P = Module and subroutine of call
+%l = Line Numbers of all nested calls
+%P = Module and subroutine of call (can be a lot of stuff!)
+%S = Just the last subroutine
+%s = Just the last line number
 %p = Process ID
 %d = Just Date (typically used internally only, use %D)
 %t = Just time (typically used internally only, use %T)
@@ -287,6 +289,17 @@ DEFAULT:  '%D %T %B %L[%P][%l] '
      P = Parent
      C = Child
 
+=item B<[loglevel]-Prefix> [pattern]
+
+You can define a prefix for a specific log level.
+
+ERR-Prefix
+WARN-Prefix
+NOTICE-Prefix
+INFO-Prefix
+DEBUG-Prefix
+DEBUGMAX-Prefix
+
 =item B<TimeStamp> [pattern]
 
 (See Log::Fast for specifics on these)
@@ -401,7 +414,8 @@ sub new {
         'TimeStamp'          => colored(['yellow on_black'], '%t'),
         'Padding'            => -15,                                  # Default padding is 15 spaces
         'CPadding'           => -2,
-        'Prefix'             => undef,
+        'Prefix'             => '%D %T %B %L[%S][%s] ',
+        'DEBUGMAX-Prefix'    => '%D %T %B %L[%P][%l] ',
         'Filename'           => '[' . colored(['magenta'],$filename) . ']',
         'ANSILevel'          => {
             'ERR'       => colored(['white on_red'],        '[ ERROR ]'),
@@ -448,9 +462,9 @@ sub new {
     } if ($self->{'COLOR'} =~ /0|FALSE|OFF/i);
     %ANSILevel = %{$self->{'ANSILEVEL'}};
 
-    # This assembles the Time and Date stamping output.  If any of the
-    # variables are blank, then that part will be disabled.
-    $self->{'PREFIX'} = '%D %T %B %L[%P][%l] ' unless (defined($self->{'PREFIX'}));
+    foreach my $lvl (@Levels) {
+        $self->{"$lvl-PREFIX"} = $self->{'PREFIX'} unless (defined($self->{"$lvl-PREFIX"}));
+    }
     # The Global loglevel is set here.
     if ($self->{'LOGLEVEL'} eq 'VERBOSE') {
         $self->{'LOG'}->level('INFO');
@@ -526,7 +540,7 @@ sub debug {
             };
         }
     }
-    my ($sname,$cline,$nested,$subroutine,$thisBench,$thisBench2) = ('','','','','','');
+    my ($sname,$cline,$nested,$subroutine,$thisBench,$thisBench2,$sline,$short) = ('','','','','','','','');
     # Figure out the proper caller tree and line number ladder
     # But only if it's part of the prefix, else don't waste time.
     if ($self->{'PREFIX'} =~ /\%(P|l)/) { # %P = Subroutine, %l = Line number(s)
@@ -546,6 +560,10 @@ sub debug {
                     $sname = $subroutine . '::' . $sname;
                     $cline = $array[2] . '/' . $cline;
                 }
+                if ($count == 2) {
+                    $short = $array[3];
+                    $sline = $array[2];
+                }
                 $nest++;
             }
             $count++;
@@ -561,6 +579,8 @@ sub debug {
                 $cline = $array[2];
             }
             $sname = 'main';
+            $sline = $cline;
+            $short = $sname;
         }
         $subroutine = $sname;
         $self->{'PADDING'}  = 0 - length($subroutine) if (length($subroutine) > abs($self->{'PADDING'}));
@@ -590,11 +610,11 @@ sub debug {
         if ($msg =~ /\n/s) {               # If the line contains newlines, then it too must be split into multiple lines.
             my @message = split(/\n/, $msg);
             foreach my $line (@message) {  # Loop through the split lines and format accordingly.
-                $self->_send_to_logger($level, $nested, $line, $first, $thisBench, $thisBench2, $subroutine, $cline);
+                $self->_send_to_logger($level, $nested, $line, $first, $thisBench, $thisBench2, $subroutine, $cline,$sline,$short);
                 $first = 0;                # Clear the first line flag.
             }
         } else {                           # This line does not contain newlines.  Treat it as a single line.
-            $self->_send_to_logger($level, $nested, $msg, $first, $thisBench, $thisBench2, $subroutine, $cline);
+            $self->_send_to_logger($level, $nested, $msg, $first, $thisBench, $thisBench2, $subroutine, $cline,$sline,$cline);
         }
         $first = 0;                        # Clear the first line flag.
     }
@@ -611,16 +631,20 @@ sub _send_to_logger {    # This actually simplifies the previous class ... serio
     my $thisBench2 = shift;
     my $subroutine = shift;
     my $cline      = shift;
+    my $sline      = shift;
+    my $shortsub   = shift;
 
     my $dt     = DateTime->now();
     my $Date   = $dt->ymd();
     my $Time   = $dt->hms();
-    my $prefix = $self->{'PREFIX'} . ''; # A copy not a pointer
+    my $prefix = $self->{$level . '-PREFIX'} . ''; # A copy not a pointer
     my $forked = ($PARENT ne $$) ? 'C' : 'P';
 
     $prefix =~ s/\%p/$$/g;
     $prefix =~ s/\%L/$ANSILevel{$level}/g;
     $prefix =~ s/\%l/$cline/g;
+    $prefix =~ s/\%s/$sline/g;
+    $prefix =~ s/\%S/$shortsub/g;
     $prefix =~ s/\%D/$self->{'DATESTAMP'}/g;
     $prefix =~ s/\%T/$self->{'TIMESTAMP'}/g;
     $prefix =~ s/\%d/$Date/g;
@@ -865,7 +889,7 @@ modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-Version 0.36    (June 13, 2015)
+Version 0.37    (June 13, 2015)
 
 =head1 BUGS
 
